@@ -15,8 +15,8 @@ class Messages_files_refsQuerySet(AuditQuerySet):
 
 class Messages_files_refsManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
         }
